// SPDX-License-Identifier: MIT
pragma solidity 0.6.10;

import {Registry} from "../Registry.sol";

contract ProvisionalRegistry is Registry {
    bytes32 constant IS_BLACKLISTED = "isBlacklisted";
    bytes32 constant IS_DEPOSIT_ADDRESS = "isDepositAddress";
    bytes32 constant IS_REGISTERED_CONTRACT = "isRegisteredContract";
    bytes32 constant CAN_BURN = "canBurn";

    function requireCanTransfer(address _from, address _to) public view returns (address, bool) {
        require(attributes[_from][IS_BLACKLISTED].value == 0, "blacklisted");
        uint256 depositAddressValue = attributes[address(uint256(_to) >> 20)][IS_DEPOSIT_ADDRESS].value;
        if (depositAddressValue != 0) {
            _to = address(depositAddressValue);
        }
        require(attributes[_to][IS_BLACKLISTED].value == 0, "blacklisted");
        return (_to, attributes[_to][IS_REGISTERED_CONTRACT].value != 0);
    }

    function requireCanTransferFrom(
        address _sender,
        address _from,
        address _to
    ) public view returns (address, bool) {
        require(attributes[_sender][IS_BLACKLISTED].value == 0, "blacklisted");
        return requireCanTransfer(_from, _to);
    }

    function requireCanMint(address _to) public view returns (address, bool) {
        require(attributes[_to][IS_BLACKLISTED].value == 0, "blacklisted");
        uint256 depositAddressValue = attributes[address(uint256(_to) >> 20)][IS_DEPOSIT_ADDRESS].value;
        if (depositAddressValue != 0) {
            _to = address(depositAddressValue);
        }
        return (_to, attributes[_to][IS_REGISTERED_CONTRACT].value != 0);
    }

    function requireCanBurn(address _from) public view {
        require(attributes[_from][CAN_BURN].value != 0);
        require(attributes[_from][IS_BLACKLISTED].value == 0);
    }
}
